SelectableHelper

Trait SelectableHelper 

pub trait SelectableHelper<DB: Backend>: Selectable<DB> + Sized {
    // Required method
    fn as_select() -> AsSelect<Self, DB>;

    // Provided method
    fn as_returning() -> AsSelect<Self, DB> { ... }
}
This helper trait provides several methods for constructing a select or returning clause based on a Selectable implementation.

Required Methods

fn as_select() -> AsSelect<Self, DB>

Construct a select clause based on a Selectable implementation.

The returned select clause enforces that you use the same type for constructing the select clause and for loading the query result into.

Provided Methods

fn as_returning() -> AsSelect<Self, DB>

An alias for as_select that can be used with returning clauses

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T, DB> SelectableHelper<DB> for T
where T: Selectable<DB>, DB: Backend,