pub struct SqlLiteral<ST, T = Empty> { /* private fields */ }Expand description
Returned by the sql() function.
Implementations
Sourceimpl<ST, T> SqlLiteral<ST, T>where
ST: TypedExpressionType,
impl<ST, T> SqlLiteral<ST, T>where
ST: TypedExpressionType,
Sourcepub fn bind<BindST, U>(
self,
bind_value: U,
) -> UncheckedBind<Self, U::Expression>
pub fn bind<BindST, U>( self, bind_value: U, ) -> UncheckedBind<Self, U::Expression>
Bind a value for use with this SQL query.
Safety
This function should be used with care, as Diesel cannot validate that the value is of the right type nor can it validate that you have passed the correct number of parameters.
Examples
let seans_id = users
.select(id)
.filter(sql::<Bool>("name = ").bind::<Text, _>("Sean"))
.get_result(connection);
assert_eq!(Ok(1), seans_id);
let tess_id = sql::<Integer>("SELECT id FROM users WHERE name = ")
.bind::<Text, _>("Tess")
.get_result(connection);
assert_eq!(Ok(2), tess_id);Multiple Bind Params
let query = users
.select(name)
.filter(
sql::<Bool>("id > ")
.bind::<Integer, _>(1)
.sql(" AND name <> ")
.bind::<Text, _>("Ryan"),
)
.get_results(connection);
let expected = vec!["Tess".to_string()];
assert_eq!(Ok(expected), query);Sourcepub fn sql(self, sql: &str) -> SqlLiteral<ST, Self>
pub fn sql(self, sql: &str) -> SqlLiteral<ST, Self>
Use literal SQL in the query builder
This function is intended for use when you need a small bit of raw SQL in
your query. If you want to write the entire query using raw SQL, use
sql_query instead.
Safety
This function should be used with care, as Diesel cannot validate that the value is of the right type nor can it validate that you have passed the correct number of parameters.
Examples
let query = users
.select(name)
.filter(sql::<Bool>("id > 1").sql(" AND name <> 'Ryan'"))
.get_results(connection);
let expected = vec!["Tess".to_string()];
assert_eq!(Ok(expected), query);Trait Implementations
Sourceimpl<ST, T, __Rhs> Add<__Rhs> for SqlLiteral<ST, T>where
Self: Expression,
<Self as Expression>::SqlType: Add,
<<Self as Expression>::SqlType as Add>::Rhs: SqlType + SingleValue,
__Rhs: AsExpression<<<Self as Expression>::SqlType as Add>::Rhs>,
impl<ST, T, __Rhs> Add<__Rhs> for SqlLiteral<ST, T>where
Self: Expression,
<Self as Expression>::SqlType: Add,
<<Self as Expression>::SqlType as Add>::Rhs: SqlType + SingleValue,
__Rhs: AsExpression<<<Self as Expression>::SqlType as Add>::Rhs>,
Sourcetype Output = Add<SqlLiteral<ST, T>, <__Rhs as AsExpression<<<SqlLiteral<ST, T> as Expression>::SqlType as Add>::Rhs>>::Expression>
type Output = Add<SqlLiteral<ST, T>, <__Rhs as AsExpression<<<SqlLiteral<ST, T> as Expression>::SqlType as Add>::Rhs>>::Expression>
The resulting type after applying the
+ operator.impl<QS, ST, T> AppearsOnTable<QS> for SqlLiteral<ST, T>where
Self: Expression,
Sourceimpl<ST: Clone, T: Clone> Clone for SqlLiteral<ST, T>
impl<ST: Clone, T: Clone> Clone for SqlLiteral<ST, T>
Sourcefn clone(&self) -> SqlLiteral<ST, T>
fn clone(&self) -> SqlLiteral<ST, T>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<ST, T, __Rhs> Div<__Rhs> for SqlLiteral<ST, T>where
Self: Expression,
<Self as Expression>::SqlType: Div,
<<Self as Expression>::SqlType as Div>::Rhs: SqlType + SingleValue,
__Rhs: AsExpression<<<Self as Expression>::SqlType as Div>::Rhs>,
impl<ST, T, __Rhs> Div<__Rhs> for SqlLiteral<ST, T>where
Self: Expression,
<Self as Expression>::SqlType: Div,
<<Self as Expression>::SqlType as Div>::Rhs: SqlType + SingleValue,
__Rhs: AsExpression<<<Self as Expression>::SqlType as Div>::Rhs>,
Sourcetype Output = Div<SqlLiteral<ST, T>, <__Rhs as AsExpression<<<SqlLiteral<ST, T> as Expression>::SqlType as Div>::Rhs>>::Expression>
type Output = Div<SqlLiteral<ST, T>, <__Rhs as AsExpression<<<SqlLiteral<ST, T> as Expression>::SqlType as Div>::Rhs>>::Expression>
The resulting type after applying the
/ operator.Sourceimpl<ST, T> Expression for SqlLiteral<ST, T>where
ST: TypedExpressionType,
impl<ST, T> Expression for SqlLiteral<ST, T>where
ST: TypedExpressionType,
Sourceimpl<ST, T, __Rhs> Mul<__Rhs> for SqlLiteral<ST, T>where
Self: Expression,
<Self as Expression>::SqlType: Mul,
<<Self as Expression>::SqlType as Mul>::Rhs: SqlType + SingleValue,
__Rhs: AsExpression<<<Self as Expression>::SqlType as Mul>::Rhs>,
impl<ST, T, __Rhs> Mul<__Rhs> for SqlLiteral<ST, T>where
Self: Expression,
<Self as Expression>::SqlType: Mul,
<<Self as Expression>::SqlType as Mul>::Rhs: SqlType + SingleValue,
__Rhs: AsExpression<<<Self as Expression>::SqlType as Mul>::Rhs>,
Sourcetype Output = Mul<SqlLiteral<ST, T>, <__Rhs as AsExpression<<<SqlLiteral<ST, T> as Expression>::SqlType as Mul>::Rhs>>::Expression>
type Output = Mul<SqlLiteral<ST, T>, <__Rhs as AsExpression<<<SqlLiteral<ST, T> as Expression>::SqlType as Mul>::Rhs>>::Expression>
The resulting type after applying the
* operator.Sourceimpl<ST, T> Query for SqlLiteral<ST, T>where
Self: Expression,
impl<ST, T> Query for SqlLiteral<ST, T>where
Self: Expression,
Sourceimpl<ST, T, DB> QueryFragment<DB> for SqlLiteral<ST, T>where
DB: Backend,
T: QueryFragment<DB>,
impl<ST, T, DB> QueryFragment<DB> for SqlLiteral<ST, T>where
DB: Backend,
T: QueryFragment<DB>,
Sourcefn walk_ast<'b>(&'b self, out: AstPass<'_, 'b, DB>) -> QueryResult<()>
fn walk_ast<'b>(&'b self, out: AstPass<'_, 'b, DB>) -> QueryResult<()>
Walk over this
QueryFragment for all passes. Read moreSourcefn to_sql(&self, out: &mut DB::QueryBuilder, backend: &DB) -> QueryResult<()>
fn to_sql(&self, out: &mut DB::QueryBuilder, backend: &DB) -> QueryResult<()>
Converts this
QueryFragment to its SQL representation. Read moreSourcefn collect_binds<'b>(
&'b self,
out: &mut DB::BindCollector<'b>,
metadata_lookup: &mut DB::MetadataLookup,
backend: &'b DB,
) -> QueryResult<()>
fn collect_binds<'b>( &'b self, out: &mut DB::BindCollector<'b>, metadata_lookup: &mut DB::MetadataLookup, backend: &'b DB, ) -> QueryResult<()>
Serializes all bind parameters in this query. Read more
Sourcefn is_safe_to_cache_prepared(&self, backend: &DB) -> QueryResult<bool>
fn is_safe_to_cache_prepared(&self, backend: &DB) -> QueryResult<bool>
Is this query safe to store in the prepared statement cache? Read more
Sourceimpl<ST, T> QueryId for SqlLiteral<ST, T>
impl<ST, T> QueryId for SqlLiteral<ST, T>
Sourceconst HAS_STATIC_QUERY_ID: bool = false
const HAS_STATIC_QUERY_ID: bool = false
Can the SQL generated by
Self be uniquely identified by its type? Read moreimpl<ST, T> RunQueryDslSupport for SqlLiteral<ST, T>
impl<QS, ST, T> SelectableExpression<QS> for SqlLiteral<ST, T>where
Self: Expression,
Sourceimpl<ST, T, __Rhs> Sub<__Rhs> for SqlLiteral<ST, T>where
Self: Expression,
<Self as Expression>::SqlType: Sub,
<<Self as Expression>::SqlType as Sub>::Rhs: SqlType + SingleValue,
__Rhs: AsExpression<<<Self as Expression>::SqlType as Sub>::Rhs>,
impl<ST, T, __Rhs> Sub<__Rhs> for SqlLiteral<ST, T>where
Self: Expression,
<Self as Expression>::SqlType: Sub,
<<Self as Expression>::SqlType as Sub>::Rhs: SqlType + SingleValue,
__Rhs: AsExpression<<<Self as Expression>::SqlType as Sub>::Rhs>,
Sourcetype Output = Sub<SqlLiteral<ST, T>, <__Rhs as AsExpression<<<SqlLiteral<ST, T> as Expression>::SqlType as Sub>::Rhs>>::Expression>
type Output = Sub<SqlLiteral<ST, T>, <__Rhs as AsExpression<<<SqlLiteral<ST, T> as Expression>::SqlType as Sub>::Rhs>>::Expression>
The resulting type after applying the
- operator.Sourceimpl<ST, T, GB> ValidGrouping<GB> for SqlLiteral<ST, T>
impl<ST, T, GB> ValidGrouping<GB> for SqlLiteral<ST, T>
Sourcetype IsAggregate = Never
type IsAggregate = Never
Is this expression aggregate? Read more